/* 
 * Copyright (c) 2009, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * */
/*
 *  ======== main.c ========
 */
#include <xdc/std.h>
#include <ti/sdo/ce/CERuntime.h>
#include <ti/sdo/ce/trace/gt.h>
#if 1
#include <ti/sdo/fc/rman/rman.h>
#include <ti/sdo/fc/ires/edma3chan/iresman_edma3Chan.h>
#include <ti/sdo/fc/ires/hdvicp/iresman_hdvicp.h>

static IRESMAN_HdVicpParams hdvicpConfig;

static IRESMAN_Edma3ChanParams edma3Config;
#include <ti/sdo/fc/edma3/edma3_config.h>
extern EDMA3_InstanceInitConfig DM6467_Config;
#endif

/* trace info: module name, mask */
static GT_Mask gtMask = {0,0};

Void makeTC0LowestPriority(Void)
{
volatile unsigned int *MSTRPRI2  = (unsigned int*) (0x01C40044);
volatile unsigned int  mstrpri2_reg;

mstrpri2_reg  = *MSTRPRI2;

mstrpri2_reg  = mstrpri2_reg & (~(7 << 0));
mstrpri2_reg  = mstrpri2_reg & (~(7 << 4));
mstrpri2_reg  = mstrpri2_reg & (~(7 << 8));
mstrpri2_reg  = mstrpri2_reg & (~(7 << 12));

mstrpri2_reg  = mstrpri2_reg | (3<<0);
mstrpri2_reg  = mstrpri2_reg | (2<<4);
mstrpri2_reg  = mstrpri2_reg | (2<<8);
mstrpri2_reg  = mstrpri2_reg | (2<<12);

*MSTRPRI2     = mstrpri2_reg;
}

/*
 *  ======== main ========
 */
Void main (Int argc, Char *argv [])
{
    int status = 0;
    /* init Codec Engine */
    CERuntime_init();

    /* init trace */
    GT_init();

    /* create a mask to allow a trace-print welcome message below */
    GT_create(&gtMask, "codec_unitserver");

    /* ...and initialize all masks in this module to "on" */
    GT_set("codec_unitserver=01234567");

    GT_0trace(gtMask, GT_4CLASS, "main> Welcome to CS3DM6467 1.00.00.00 DSP server's main().\n");
#if 1
    edma3Config.baseConfig.allocFxn = RMAN_PARAMS.allocFxn;
    edma3Config.baseConfig.freeFxn = RMAN_PARAMS.freeFxn;
    edma3Config.baseConfig.size = sizeof(IRESMAN_Edma3ChanParams);
    status = RMAN_register(&IRESMAN_EDMA3CHAN, (IRESMAN_Params *)&edma3Config);

    hdvicpConfig.numResources = 2;
    hdvicpConfig.baseConfig.allocFxn = RMAN_PARAMS.allocFxn;
    hdvicpConfig.baseConfig.freeFxn = RMAN_PARAMS.freeFxn;
    status = RMAN_register(&IRESMAN_HDVICP, (IRESMAN_Params *)&hdvicpConfig);
#endif

    /* Make TC0 Lowest Priority*/
     makeTC0LowestPriority();

}

#define DMA_CHANNEL_TO_EVENT_MAPPING_0          (0x0)
#define DMA_CHANNEL_TO_EVENT_MAPPING_1          (0x0)

EDMA3_InstanceInitConfig DM6467_Config = 
          {
            /* Resources owned by Region 1 */
            /* ownPaRAMSets */
            {0x0u, 0x0u, 0x0u, 0x0u,
            0xFFFFFFFFu, 0xFFFFFFFFu, 0xFFFFFFFFu, 0xFFFFFFFFu,
            0xFFFFFFFFu, 0xFFFFFFFFu, 0xFFFFFFFFu, 0xFFFFFFFFu,
            0xFFFFFFFFu, 0xFFFFFFFFu, 0xFFFFFFFFu, 0xFFFFFFFFu},

            /* ownDmaChannels */
            { 0xFFF0E00Fu, 0xFF3FFFFFu},

            /* ownQdmaChannels */
            {0x0000007Fu},

            /* ownTccs */
/*             {0xCF00E00Fu, 0xFF00F800u},*/
            { 0xFFF0E00Fu, 0xFF3FFFFFu},

            /* Resources reserved by Region 1 */
            /* resvdPaRAMSets */
            {0x0u, 0x0u, 0x0u, 0x0u,
            0x0u, 0x0u, 0x0u, 0x0u,
            0x0u, 0x0u, 0x0u, 0x0u,
            0x0u, 0x0u, 0x0u, 0x0u},

            /* resvdDmaChannels */
            {DMA_CHANNEL_TO_EVENT_MAPPING_0, DMA_CHANNEL_TO_EVENT_MAPPING_1},

            /* resvdQdmaChannels */
            {0x0u},

            /* resvdTccs */
            {DMA_CHANNEL_TO_EVENT_MAPPING_0, DMA_CHANNEL_TO_EVENT_MAPPING_1},
          };

/*
 *  @(#) ti.sdo.ce.wizards.genserver; 1, 0, 0,29; 9-12-2009 17:16:21; /db/atree/library/trees/ce/ce-o01x/src/
 */
